import * as react from 'react';
import * as hast from 'hast';

declare const SUPPORTED_LANGUAGES: readonly ["1c", "abnf", "accesslog", "actionscript", "ada", "angelscript", "apache", "applescript", "arcade", "arduino", "armasm", "asciidoc", "aspectj", "autohotkey", "autoit", "avrasm", "awk", "axapta", "bash", "basic", "bnf", "brainfuck", "c", "cal", "capnproto", "ceylon", "clean", "clojure-repl", "clojure", "cmake", "coffeescript", "coq", "cos", "cpp", "crmsh", "crystal", "csharp", "csp", "css", "d", "dart", "delphi", "diff", "django", "dns", "dockerfile", "dos", "dsconfig", "dts", "dust", "ebnf", "elixir", "elm", "erb", "erlang-repl", "erlang", "excel", "fix", "flix", "fortran", "fsharp", "gams", "gauss", "gcode", "gherkin", "glsl", "gml", "go", "golo", "gradle", "graphql", "groovy", "haml", "handlebars", "haskell", "haxe", "hsp", "http", "hy", "inform7", "ini", "irpf90", "isbl", "java", "javascript", "jboss-cli", "json", "julia-repl", "julia", "kotlin", "lasso", "latex", "ldif", "leaf", "less", "lisp", "livecodeserver", "livescript", "llvm", "lsl", "lua", "makefile", "markdown", "mathematica", "matlab", "maxima", "mel", "mercury", "mipsasm", "mizar", "mojolicious", "monkey", "moonscript", "n1ql", "nestedtext", "nginx", "nim", "nix", "node-repl", "nsis", "objectivec", "ocaml", "openscad", "oxygene", "parser3", "perl", "pf", "pgsql", "php-template", "php", "plaintext", "pony", "powershell", "processing", "profile", "prolog", "properties", "protobuf", "puppet", "purebasic", "python-repl", "python", "q", "qml", "r", "reasonml", "rib", "roboconf", "routeros", "rsl", "ruby", "ruleslanguage", "rust", "sas", "scala", "scheme", "scilab", "scss", "shell", "smali", "smalltalk", "sml", "sqf", "sql", "stan", "stata", "step21", "stylus", "subunit", "swift", "taggerscript", "tap", "tcl", "thrift", "tp", "twig", "typescript", "vala", "vbnet", "vbscript-html", "vbscript", "verilog", "vhdl", "vim", "wasm", "wren", "x86asm", "xl", "xml", "xquery", "yaml", "zephir"];
type SupportedLanguage = (typeof SUPPORTED_LANGUAGES)[number];

type Text = hast.Text;
type Span = {
    type: 'element';
    tagName: 'span';
    properties: {
        className: Array<string>;
    };
    children: Array<Span | Text>;
};

declare const a11yDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const a11yLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const agate: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-meta-keyword': {
        fontWeight: string;
    };
    'hljs-name': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-code': {
        fontStyle: string;
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-meta-string': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-tag .hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-deletion': {
        background: string;
        color: string;
    };
    'hljs-addition': {
        background: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs mark': {
        background: string;
        color: string;
    };
};

declare const anOldHope: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const androidstudio: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const arduinoLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-number': {
        color: string;
    };
};

declare const arta: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const ascetic: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-keyword': {
        fontWeight: string;
    };
    'hljs-name': {
        fontWeight: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-type': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const atomOneDarkReasonable: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-pattern-match': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-pattern-match .hljs-constructor': {
        color: string;
    };
    'hljs-function .hljs-params': {
        color: string;
    };
    'hljs-function .hljs-params .hljs-typing': {
        color: string;
    };
    'hljs-module-access .hljs-module': {
        color: string;
    };
    'hljs-constructor': {
        color: string;
    };
    'hljs-constructor .hljs-string': {
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
        textDecoration: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const atomOneDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
        textDecoration: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const atomOneLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
        textDecoration: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const brownPaper: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-type': {
        color: string;
        fontWeight: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const codepenEmbed: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const colorBrewer: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-strong': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-attribute': {
        color: string;
    };
};

declare const dark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-type': {
        color: string;
        fontWeight: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const defaultStyle: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-punctuation': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-tag .hljs-attr': {
        color: string;
    };
    'hljs-tag .hljs-name': {
        color: string;
    };
    'hljs-attribute': {
        fontWeight: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-keyword': {
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        fontWeight: string;
    };
    'hljs-name': {
        fontWeight: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const devibeans: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const docco: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-attribute': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-meta': {
        color: string;
        fontWeight: string;
    };
    'hljs-deletion': {
        background: string;
    };
    'hljs-addition': {
        background: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const far: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-title': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const felipec: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs ::selection': {
        color: string;
        background: string;
    };
    'hljs::selection': {
        color: string;
        background: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-punctuation': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const foundation: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-strong': {
        color: string;
        fontWeight: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-regexp': {
        backgroundColor: string;
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
};

declare const githubDarkDimmed: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-title.class_.inherited__': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-strong': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
        backgroundColor: string;
    };
    'hljs-deletion': {
        color: string;
        backgroundColor: string;
    };
};

declare const githubDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-title.class_.inherited__': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-strong': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
        backgroundColor: string;
    };
    'hljs-deletion': {
        color: string;
        backgroundColor: string;
    };
};

declare const github: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-title.class_.inherited__': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-strong': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
        backgroundColor: string;
    };
    'hljs-deletion': {
        color: string;
        backgroundColor: string;
    };
};

declare const gml: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const googlecode: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
        fontWeight: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-formula': {
        backgroundColor: string;
        fontStyle: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-addition': {
        backgroundColor: string;
    };
    'hljs-deletion': {
        backgroundColor: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const gradientDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        backgroundColor: string;
        backgroundImage: string;
        color: string;
    };
    'hljs-subtr': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-params': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-class': {
        color: string;
        fontWeight: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const gradientLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        backgroundColor: string;
        backgroundImage: string;
        color: string;
    };
    'hljs-subtr': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-params': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-class': {
        color: string;
        fontWeight: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const grayscale: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-subst': {
        color: string;
        fontWeight: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
        background: string;
    };
    'hljs-formula': {
        color: string;
        background: string;
    };
    'hljs-string': {
        color: string;
        background: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-id': {
        color: string;
        fontWeight: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-class .hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-title.class_': {
        color: string;
        fontWeight: string;
    };
    'hljs-type': {
        color: string;
        fontWeight: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
        background: string;
    };
    'hljs-bullet': {
        color: string;
        background: string;
    };
    'hljs-link': {
        color: string;
        background: string;
    };
    'hljs-symbol': {
        color: string;
        background: string;
    };
    'hljs-built_in': {
        color: string;
        textDecoration: string;
    };
    'hljs-meta': {
        color: string;
        fontWeight: string;
    };
    'hljs-deletion': {
        color: string;
        background: string;
    };
    'hljs-addition': {
        color: string;
        background: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const hybrid: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs span::selection': {
        background: string;
    };
    'hljs::selection': {
        background: string;
    };
    'hljs span::-moz-selection': {
        background: string;
    };
    'hljs::-moz-selection': {
        background: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const idea: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-subst': {
        fontWeight: string;
        color: string;
    };
    'hljs-title': {
        fontWeight: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-tag': {
        background: string;
    };
    'hljs-keyword': {
        fontWeight: string;
        color: string;
    };
    'hljs-literal': {
        fontWeight: string;
        color: string;
    };
    'hljs-name': {
        fontWeight: string;
        color: string;
    };
    'hljs-section': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-class': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-id': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
        color: string;
    };
    'hljs-type': {
        fontWeight: string;
        color: string;
    };
    'hljs-attribute': {
        fontWeight: string;
        color: string;
    };
    'hljs-link': {
        fontWeight: string;
        color: string;
    };
    'hljs-number': {
        fontWeight: string;
        color: string;
    };
    'hljs-regexp': {
        fontWeight: string;
        color: string;
    };
    'hljs-string': {
        color: string;
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
        background: string;
        fontStyle: string;
    };
    'hljs-formula': {
        color: string;
        background: string;
        fontStyle: string;
    };
    'hljs-symbol': {
        color: string;
        background: string;
        fontStyle: string;
    };
    'hljs-doctag': {
        textDecoration: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-addition': {
        background: string;
    };
    'hljs-deletion': {
        background: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const intellijLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-subst': {
        fontWeight: string;
        color: string;
    };
    'hljs-title': {
        fontWeight: string;
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-code': {
        color: string;
        fontStyle: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-link': {
        textDecoration: string;
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-char.escape_': {
        color: string;
    };
    'hljs-doctag': {
        textDecoration: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-addition': {
        background: string;
    };
    'hljs-deletion': {
        background: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const irBlack: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const isblEditorDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-attribute': {
        color: string;
        fontWeight: string;
    };
    'hljs-doctag': {
        color: string;
        fontWeight: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
        fontWeight: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-class': {
        color: string;
        fontWeight: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-title>.hljs-built_in': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const isblEditorLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-attribute': {
        color: string;
        fontWeight: string;
    };
    'hljs-doctag': {
        color: string;
        fontWeight: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
        fontWeight: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-class': {
        color: string;
        fontWeight: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-title>.hljs-built_in': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const kimbieDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const kimbieLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const lightfair: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-attribute': {
        fontWeight: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-keyword': {
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        fontWeight: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const lioshi: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-subst .hljs-link': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const magula: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        backgroundColor: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-built_in': {
        fontWeight: string;
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
        color: string;
    };
    'hljs-keyword': {
        fontWeight: string;
        color: string;
    };
    'hljs-name': {
        fontWeight: string;
        color: string;
    };
    'hljs-section': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
        color: string;
    };
    'hljs-tag': {
        fontWeight: string;
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const monoBlue: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-keyword': {
        fontWeight: string;
    };
    'hljs-name': {
        fontWeight: string;
        color: string;
    };
    'hljs-section': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-title': {
        fontWeight: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const monokaiSublime: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-strong': {
        color: string;
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
};

declare const monokai: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-strong': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-type': {
        color: string;
        fontWeight: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-selector-id': {
        fontWeight: string;
    };
};

declare const nightOwl: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-keyword': {
        color: string;
        fontStyle: string;
    };
    'hljs-built_in': {
        color: string;
        fontStyle: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontStyle: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-strong': {
        color: string;
        fontWeight: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
        fontStyle: string;
    };
    'hljs-selector-attr': {
        color: string;
        fontStyle: string;
    };
    'hljs-selector-pseudo': {
        color: string;
        fontStyle: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-addition': {
        color: string;
        fontStyle: string;
    };
    'hljs-deletion': {
        color: string;
        fontStyle: string;
    };
};

declare const nnfxDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'language-xml .hljs-meta': {
        fontWeight: string;
        fontStyle: string;
        color: string;
    };
    'language-xml .hljs-meta-string': {
        fontWeight: string;
        fontStyle: string;
        color: string;
    };
    'hljs-comment': {
        fontStyle: string;
        color: string;
    };
    'hljs-quote': {
        fontStyle: string;
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-attr': {
        fontWeight: string;
        color: string;
    };
    'hljs-string': {
        fontWeight: string;
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-class .hljs-title': {
        fontWeight: string;
        color: string;
    };
    'hljs-title.class_': {
        fontWeight: string;
        color: string;
    };
    'hljs-type': {
        fontWeight: string;
        color: string;
    };
    'hljs-function .hljs-title': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-formula': {
        backgroundColor: string;
        fontStyle: string;
    };
    'hljs-addition': {
        backgroundColor: string;
    };
    'hljs-deletion': {
        backgroundColor: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-section': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-class': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-id': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-pseudo': {
        fontWeight: string;
        color: string;
        fontStyle: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const nnfxLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'language-xml .hljs-meta': {
        fontWeight: string;
        fontStyle: string;
        color: string;
    };
    'language-xml .hljs-meta-string': {
        fontWeight: string;
        fontStyle: string;
        color: string;
    };
    'hljs-comment': {
        fontStyle: string;
        color: string;
    };
    'hljs-quote': {
        fontStyle: string;
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-attr': {
        fontWeight: string;
        color: string;
    };
    'hljs-string': {
        fontWeight: string;
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-class .hljs-title': {
        fontWeight: string;
        color: string;
    };
    'hljs-title.class_': {
        fontWeight: string;
        color: string;
    };
    'hljs-type': {
        fontWeight: string;
        color: string;
    };
    'hljs-function .hljs-title': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-formula': {
        backgroundColor: string;
        fontStyle: string;
    };
    'hljs-addition': {
        backgroundColor: string;
    };
    'hljs-deletion': {
        backgroundColor: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-section': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-class': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-id': {
        fontWeight: string;
        color: string;
    };
    'hljs-selector-pseudo': {
        fontWeight: string;
        color: string;
        fontStyle: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const nord: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-addition': {
        backgroundColor: string;
    };
    'hljs-deletion': {
        backgroundColor: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-function>.hljs-title': {
        color: string;
    };
    'hljs-title.hljs-function': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-link:hover': {
        textDecoration: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'language-abnf .hljs-attribute': {
        color: string;
    };
    'language-abnf .hljs-symbol': {
        color: string;
    };
    'language-apache .hljs-attribute': {
        color: string;
    };
    'language-apache .hljs-section': {
        color: string;
    };
    'language-arduino .hljs-built_in': {
        color: string;
    };
    'language-aspectj .hljs-meta': {
        color: string;
    };
    'language-aspectj>.hljs-title': {
        color: string;
    };
    'language-bnf .hljs-attribute': {
        color: string;
    };
    'language-clojure .hljs-name': {
        color: string;
    };
    'language-clojure .hljs-symbol': {
        color: string;
    };
    'language-coq .hljs-built_in': {
        color: string;
    };
    'language-cpp .hljs-meta .hljs-string': {
        color: string;
    };
    'language-css .hljs-built_in': {
        color: string;
    };
    'language-css .hljs-keyword': {
        color: string;
    };
    'language-diff .hljs-meta': {
        color: string;
    };
    'language-ebnf .hljs-attribute': {
        color: string;
    };
    'language-glsl .hljs-built_in': {
        color: string;
    };
    'language-groovy .hljs-meta:not(:first-child)': {
        color: string;
    };
    'language-haxe .hljs-meta': {
        color: string;
    };
    'language-java .hljs-meta': {
        color: string;
    };
    'language-ldif .hljs-attribute': {
        color: string;
    };
    'language-lisp .hljs-name': {
        color: string;
    };
    'language-lua .hljs-built_in': {
        color: string;
    };
    'language-moonscript .hljs-built_in': {
        color: string;
    };
    'language-nginx .hljs-attribute': {
        color: string;
    };
    'language-nginx .hljs-section': {
        color: string;
    };
    'language-pf .hljs-built_in': {
        color: string;
    };
    'language-processing .hljs-built_in': {
        color: string;
    };
    'language-scss .hljs-keyword': {
        color: string;
    };
    'language-stylus .hljs-keyword': {
        color: string;
    };
    'language-swift .hljs-meta': {
        color: string;
    };
    'language-vim .hljs-built_in': {
        color: string;
        fontStyle: string;
    };
    'language-yaml .hljs-meta': {
        color: string;
    };
};

declare const obsidian: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-emphasis': {
        color: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
        fontWeight: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-section': {
        fontWeight: string;
        color: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-title': {
        fontWeight: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
};

declare const pandaSyntaxDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-link': {
        textDecoration: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-punctuation': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-char.escape_': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-title.class_.inherited__': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
};

declare const pandaSyntaxLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-link': {
        textDecoration: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-punctuation': {
        color: string;
    };
    'hljs-char.escape_': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-title.class_.inherited__': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
};

declare const paraisoDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const paraisoLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const pojoaque: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-formula': {
        background: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const purebasic: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
        fontWeight: string;
    };
    'hljs-class': {
        color: string;
        fontWeight: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-class': {
        color: string;
        fontWeight: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-meta': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-id': {
        color: string;
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const qtcreatorDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-strong': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-code .hljs-selector-class': {
        color: string;
    };
    'hljs-stronge': {
        fontStyle: string;
    };
    'hljs-type': {
        fontStyle: string;
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
};

declare const qtcreatorLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-emphasis': {
        color: string;
        fontStyle: string;
    };
    'hljs-strong': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-code .hljs-selector-class': {
        color: string;
    };
    'hljs-stronge': {
        fontStyle: string;
    };
    'hljs-type': {
        fontStyle: string;
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
};

declare const rainbow: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-formula': {
        background: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const routeros: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-keyword': {
        fontWeight: string;
    };
    'hljs-meta .hljs-keyword': {
        fontWeight: string;
    };
    'hljs-name': {
        fontWeight: string;
    };
    'hljs-selector-tag': {
        fontWeight: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const schoolBook: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-section': {
        color: string;
        fontWeight: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-type': {
        color: string;
        fontWeight: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-name': {
        fontWeight: string;
    };
    'hljs-selector-id': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const shadesOfPurple: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
        fontWeight: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-attr': {
        color: string;
        fontStyle: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
        fontWeight: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-literal': {
        fontWeight: string;
        color: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const srcery: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const stackoverflowDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const stackoverflowLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const sunburst: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-class .hljs-title': {
        textDecoration: string;
    };
    'hljs-doctag': {
        textDecoration: string;
    };
    'hljs-title.class_': {
        textDecoration: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-formula': {
        backgroundColor: string;
        color: string;
        fontStyle: string;
    };
    'hljs-addition': {
        backgroundColor: string;
        color: string;
    };
    'hljs-deletion': {
        backgroundColor: string;
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const tokyoNightDark: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-title.class_.inherited__': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-char.escape_': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-punctuation': {
        color: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const tokyoNightLight: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-variable.language_': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-property': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-title.class_.inherited__': {
        color: string;
    };
    'hljs-title.function_': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-char.escape_': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-operator': {
        color: string;
    };
    'hljs-punctuation': {
        color: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const tomorrowNightBlue: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const tomorrowNightBright: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const vs: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-addition': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-deletion': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
};

declare const vs2015: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-link': {
        color: string;
        textDecoration: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-class': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-template-tag': {
        color: string;
    };
    'hljs-formula': {
        color: string;
    };
    'hljs-function': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-comment': {
        color: string;
        fontStyle: string;
    };
    'hljs-quote': {
        color: string;
        fontStyle: string;
    };
    'hljs-doctag': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-meta .hljs-keyword': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-selector-attr': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-selector-pseudo': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-addition': {
        backgroundColor: string;
        display: string;
        width: string;
    };
    'hljs-deletion': {
        backgroundColor: string;
        display: string;
        width: string;
    };
};

declare const xcode: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        background: string;
        color: string;
    };
    'xml .hljs-meta': {
        color: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-literal': {
        color: string;
    };
    'hljs-name': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
    };
    'hljs-variable': {
        color: string;
    };
    'hljs-code': {
        color: string;
    };
    'hljs-meta .hljs-string': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-number': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-title': {
        color: string;
    };
    'hljs-meta': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-class .hljs-title': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-title.class_': {
        color: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-attr': {
        color: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-formula': {
        backgroundColor: string;
        fontStyle: string;
    };
    'hljs-addition': {
        backgroundColor: string;
    };
    'hljs-deletion': {
        backgroundColor: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-doctag': {
        fontWeight: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
};

declare const xt256: {
    're code.hljs': {
        display: string;
        overflowX: string;
        padding: string;
    };
    'ode.hljs': {
        padding: string;
    };
    hljs: {
        color: string;
        background: string;
    };
    'hljs-subst': {
        color: string;
    };
    'hljs-emphasis': {
        fontStyle: string;
    };
    'hljs-strong': {
        fontWeight: string;
    };
    'hljs-type': {
        color: string;
    };
    'hljs-params': {
        color: string;
    };
    'hljs-literal': {
        color: string;
        fontWeight: string;
    };
    'hljs-name': {
        color: string;
        fontWeight: string;
    };
    'hljs-number': {
        color: string;
        fontWeight: string;
    };
    'hljs-comment': {
        color: string;
    };
    'hljs-quote': {
        color: string;
    };
    'hljs-selector-id': {
        color: string;
    };
    'hljs-template-variable': {
        color: string;
        fontWeight: string;
    };
    'hljs-title': {
        color: string;
        fontWeight: string;
    };
    'hljs-variable': {
        color: string;
        fontWeight: string;
    };
    'hljs-keyword': {
        color: string;
    };
    'hljs-selector-class': {
        color: string;
    };
    'hljs-symbol': {
        color: string;
    };
    'hljs-bullet': {
        color: string;
    };
    'hljs-string': {
        color: string;
    };
    'hljs-section': {
        color: string;
    };
    'hljs-tag': {
        color: string;
    };
    'hljs-selector-tag': {
        color: string;
        fontWeight: string;
    };
    'hljs-attribute': {
        color: string;
    };
    'hljs-built_in': {
        color: string;
    };
    'hljs-link': {
        color: string;
    };
    'hljs-regexp': {
        color: string;
    };
    'hljs-meta': {
        color: string;
        fontWeight: string;
    };
};

declare const styles_a11yDark: typeof a11yDark;
declare const styles_a11yLight: typeof a11yLight;
declare const styles_agate: typeof agate;
declare const styles_anOldHope: typeof anOldHope;
declare const styles_androidstudio: typeof androidstudio;
declare const styles_arduinoLight: typeof arduinoLight;
declare const styles_arta: typeof arta;
declare const styles_ascetic: typeof ascetic;
declare const styles_atomOneDark: typeof atomOneDark;
declare const styles_atomOneDarkReasonable: typeof atomOneDarkReasonable;
declare const styles_atomOneLight: typeof atomOneLight;
declare const styles_brownPaper: typeof brownPaper;
declare const styles_codepenEmbed: typeof codepenEmbed;
declare const styles_colorBrewer: typeof colorBrewer;
declare const styles_dark: typeof dark;
declare const styles_defaultStyle: typeof defaultStyle;
declare const styles_devibeans: typeof devibeans;
declare const styles_docco: typeof docco;
declare const styles_far: typeof far;
declare const styles_felipec: typeof felipec;
declare const styles_foundation: typeof foundation;
declare const styles_github: typeof github;
declare const styles_githubDark: typeof githubDark;
declare const styles_githubDarkDimmed: typeof githubDarkDimmed;
declare const styles_gml: typeof gml;
declare const styles_googlecode: typeof googlecode;
declare const styles_gradientDark: typeof gradientDark;
declare const styles_gradientLight: typeof gradientLight;
declare const styles_grayscale: typeof grayscale;
declare const styles_hybrid: typeof hybrid;
declare const styles_idea: typeof idea;
declare const styles_intellijLight: typeof intellijLight;
declare const styles_irBlack: typeof irBlack;
declare const styles_isblEditorDark: typeof isblEditorDark;
declare const styles_isblEditorLight: typeof isblEditorLight;
declare const styles_kimbieDark: typeof kimbieDark;
declare const styles_kimbieLight: typeof kimbieLight;
declare const styles_lightfair: typeof lightfair;
declare const styles_lioshi: typeof lioshi;
declare const styles_magula: typeof magula;
declare const styles_monoBlue: typeof monoBlue;
declare const styles_monokai: typeof monokai;
declare const styles_monokaiSublime: typeof monokaiSublime;
declare const styles_nightOwl: typeof nightOwl;
declare const styles_nnfxDark: typeof nnfxDark;
declare const styles_nnfxLight: typeof nnfxLight;
declare const styles_nord: typeof nord;
declare const styles_obsidian: typeof obsidian;
declare const styles_pandaSyntaxDark: typeof pandaSyntaxDark;
declare const styles_pandaSyntaxLight: typeof pandaSyntaxLight;
declare const styles_paraisoDark: typeof paraisoDark;
declare const styles_paraisoLight: typeof paraisoLight;
declare const styles_pojoaque: typeof pojoaque;
declare const styles_purebasic: typeof purebasic;
declare const styles_qtcreatorDark: typeof qtcreatorDark;
declare const styles_qtcreatorLight: typeof qtcreatorLight;
declare const styles_rainbow: typeof rainbow;
declare const styles_routeros: typeof routeros;
declare const styles_schoolBook: typeof schoolBook;
declare const styles_shadesOfPurple: typeof shadesOfPurple;
declare const styles_srcery: typeof srcery;
declare const styles_stackoverflowDark: typeof stackoverflowDark;
declare const styles_stackoverflowLight: typeof stackoverflowLight;
declare const styles_sunburst: typeof sunburst;
declare const styles_tokyoNightDark: typeof tokyoNightDark;
declare const styles_tokyoNightLight: typeof tokyoNightLight;
declare const styles_tomorrowNightBlue: typeof tomorrowNightBlue;
declare const styles_tomorrowNightBright: typeof tomorrowNightBright;
declare const styles_vs: typeof vs;
declare const styles_vs2015: typeof vs2015;
declare const styles_xcode: typeof xcode;
declare const styles_xt256: typeof xt256;
declare namespace styles {
  export { styles_a11yDark as a11yDark, styles_a11yLight as a11yLight, styles_agate as agate, styles_anOldHope as anOldHope, styles_androidstudio as androidstudio, styles_arduinoLight as arduinoLight, styles_arta as arta, styles_ascetic as ascetic, styles_atomOneDark as atomOneDark, styles_atomOneDarkReasonable as atomOneDarkReasonable, styles_atomOneLight as atomOneLight, styles_brownPaper as brownPaper, styles_codepenEmbed as codepenEmbed, styles_colorBrewer as colorBrewer, styles_dark as dark, styles_defaultStyle as defaultStyle, styles_devibeans as devibeans, styles_docco as docco, styles_far as far, styles_felipec as felipec, styles_foundation as foundation, styles_github as github, styles_githubDark as githubDark, styles_githubDarkDimmed as githubDarkDimmed, styles_gml as gml, styles_googlecode as googlecode, styles_gradientDark as gradientDark, styles_gradientLight as gradientLight, styles_grayscale as grayscale, styles_hybrid as hybrid, styles_idea as idea, styles_intellijLight as intellijLight, styles_irBlack as irBlack, styles_isblEditorDark as isblEditorDark, styles_isblEditorLight as isblEditorLight, styles_kimbieDark as kimbieDark, styles_kimbieLight as kimbieLight, styles_lightfair as lightfair, styles_lioshi as lioshi, styles_magula as magula, styles_monoBlue as monoBlue, styles_monokai as monokai, styles_monokaiSublime as monokaiSublime, styles_nightOwl as nightOwl, styles_nnfxDark as nnfxDark, styles_nnfxLight as nnfxLight, styles_nord as nord, styles_obsidian as obsidian, styles_pandaSyntaxDark as pandaSyntaxDark, styles_pandaSyntaxLight as pandaSyntaxLight, styles_paraisoDark as paraisoDark, styles_paraisoLight as paraisoLight, styles_pojoaque as pojoaque, styles_purebasic as purebasic, styles_qtcreatorDark as qtcreatorDark, styles_qtcreatorLight as qtcreatorLight, styles_rainbow as rainbow, styles_routeros as routeros, styles_schoolBook as schoolBook, styles_shadesOfPurple as shadesOfPurple, styles_srcery as srcery, styles_stackoverflowDark as stackoverflowDark, styles_stackoverflowLight as stackoverflowLight, styles_sunburst as sunburst, styles_tokyoNightDark as tokyoNightDark, styles_tokyoNightLight as tokyoNightLight, styles_tomorrowNightBlue as tomorrowNightBlue, styles_tomorrowNightBright as tomorrowNightBright, styles_vs as vs, styles_vs2015 as vs2015, styles_xcode as xcode, styles_xt256 as xt256 };
}

type StyleName = keyof typeof styles;
type StyleSheet = (typeof styles)[keyof typeof styles];
/** The children returned by the {@linkcode lowlight.highlight} function */
type Tree = Array<Span | Text>;
/** A node in the {@linkcode Tree} */
type Node = Span | Text;

type SyntaxHighlighterProps = {
    language?: SupportedLanguage;
    styleName?: StyleName;
    wrapLines?: boolean;
    children: string;
};
declare const SyntaxHighlighter: ({ children, wrapLines, language, styleName, }: SyntaxHighlighterProps) => react.JSX.Element;

export { type Node, SUPPORTED_LANGUAGES, type StyleName, type StyleSheet, type SupportedLanguage, SyntaxHighlighter, type SyntaxHighlighterProps, type Tree };
